Index: test/mjsunit/limit-locals.js |
diff --git a/test/mjsunit/limit-locals.js b/test/mjsunit/limit-locals.js |
index ad9ec43686e9366f7d7b4f4ddec3b1af7f6566c7..22f895c71492365bbdf69ef4d037bd05fc297bfc 100644 |
--- a/test/mjsunit/limit-locals.js |
+++ b/test/mjsunit/limit-locals.js |
@@ -25,7 +25,7 @@ |
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE |
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. |
// Test that there is a limit of 32767 locals. |
function function_with_n_locals(n) { |
test_prefix = "prefix "; |
@@ -41,6 +41,7 @@ function function_with_n_locals(n) { |
assertEquals("prefix 0 suffix", function_with_n_locals(0)); |
assertEquals("prefix 16000 suffix", function_with_n_locals(16000)); |
assertEquals("prefix 32767 suffix", function_with_n_locals(32767)); |
+assertEquals("prefix 65535 suffix", function_with_n_locals(65535)); |
-assertThrows("function_with_n_locals(32768)"); |
+assertThrows("function_with_n_locals(65536)"); |
assertThrows("function_with_n_locals(100000)"); |
@@ -25,7 +25,7 @@ |
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE |
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. |
-// Test that there is a limit of 32767 locals. |
+// Test that there is a limit of 65535 locals. |
function function_with_n_locals(n) { |
test_prefix = "prefix "; |